@@ -70,14 +70,19 @@ class RunLoop(object):
     def run(self):
         self.running = True
         while self.running:
-            start_time = time.time()
-
             if len(self.timers) > 0:
-                next_timer = self.timers.pop()
-                if next_timer.active:
-                    try:
-                        self._wait(next_timer.next_fire_time)
+                try:
+                    self._wait(self.timers[-1].next_fire_time)
+                except Exception as e:
+                    self._error(e)
+                    continue
 
+                next_timer = self.timers.pop()
+
+                if next_timer.active:
+                    before_action_time = time.time()
+
+                    try:
                         self._before_action_callbacks()
                         next_timer.run()
                         self._after_action_callbacks()
@@ -85,11 +90,11 @@ class RunLoop(object):
                         self._error(e)
                     finally:
                         if next_timer.repeating and next_timer.active:
-                            next_timer.next_fire_time = start_time + next_timer.period
+                            next_timer.next_fire_time = before_action_time + next_timer.period
                             self.schedule(next_timer)
             else:
                 try:
-                    self._wait(start_time + 0.1)
+                    self._wait(time.time() + 0.1)
                 except Exception as e:
                     self._error(e)
 
